# Generated by Django 4.1.7 on 2023-03-03 23:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0009_associatebalance'),
    ]

    operations = [
        migrations.CreateModel(
            name='Operation',
            fields=[
                ('companyid', models.IntegerField(db_column='companyid', primary_key=True, serialize=False)),
                ('documentid', models.CharField(max_length=3)),
                ('numberid', models.IntegerField()),
                ('locationid', models.IntegerField(db_column='locationid')),
                ('date', models.DateField(blank=True, db_column='"Date"', null=True)),
                ('hour', models.DateField(blank=True, null=True)),
                ('clientid', models.BigIntegerField(blank=True, null=True)),
                ('directionid', models.IntegerField(blank=True, null=True)),
                ('vendorid', models.BigIntegerField(blank=True, null=True)),
                ('conceptid', models.CharField(blank=True, max_length=3, null=True)),
                ('motiveid', models.IntegerField(blank=True, null=True)),
                ('conditionpaymentid', models.IntegerField(blank=True, null=True)),
                ('typepriceid', models.IntegerField(blank=True, null=True)),
                ('discountpercentage', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('discountpercentage2', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('promptpaymentid', models.IntegerField(blank=True, null=True)),
                ('promptpayment', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('pricetax', models.CharField(blank=True, max_length=1, null=True)),
                ('quantity', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('weight', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('volume', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('brute', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('discount', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('subtotal', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('tax', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('taxsale', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('imco', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('total', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('retention', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('retentiontaxsale', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('retentionica', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('retentioncre', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('net', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('payment', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('change', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('paid', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('totalcost', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('totalsupplier', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('adjustment', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('documentid1', models.CharField(blank=True, max_length=3, null=True)),
                ('numberid1', models.IntegerField(blank=True, null=True)),
                ('numberid2', models.IntegerField(blank=True, null=True)),
                ('numberid3', models.IntegerField(blank=True, null=True)),
                ('cashid', models.IntegerField(blank=True, null=True)),
                ('warehouseid', models.IntegerField(blank=True, null=True)),
                ('invstate', models.BooleanField(blank=True, null=True)),
                ('inventory', models.BooleanField(blank=True, null=True)),
                ('destinylocationid', models.IntegerField(blank=True, null=True)),
                ('box', models.IntegerField(blank=True, null=True)),
                ('formpaymentid', models.IntegerField(blank=True, null=True)),
                ('confirmdate', models.DateField(blank=True, null=True)),
                ('confirmhour', models.DateField(blank=True, null=True)),
                ('printdate', models.DateField(blank=True, null=True)),
                ('printhour', models.DateField(blank=True, null=True)),
                ('prefix', models.CharField(blank=True, max_length=10, null=True)),
                ('currencyid', models.IntegerField(blank=True, null=True)),
                ('exchangerate', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('saledate', models.DateField(blank=True, null=True)),
                ('quota', models.BooleanField(blank=True, null=True)),
                ('bond', models.BooleanField(blank=True, null=True)),
                ('quotavalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('zoneid', models.IntegerField(blank=True, null=True)),
                ('origin', models.BooleanField(blank=True, null=True)),
                ('totaltranscription', models.IntegerField(blank=True, null=True)),
                ('transcription', models.IntegerField(blank=True, null=True)),
                ('bondvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('bondtax', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('turnid', models.IntegerField(blank=True, null=True)),
                ('freight', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('secure', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('pointsadd', models.IntegerField(blank=True, null=True)),
                ('pointsrest', models.IntegerField(blank=True, null=True)),
                ('vehicleid', models.CharField(blank=True, max_length=10, null=True)),
                ('businessid', models.IntegerField(blank=True, null=True)),
                ('projectid', models.IntegerField(blank=True, null=True)),
                ('affiliateid', models.BigIntegerField(blank=True, null=True)),
                ('documentlocationid', models.IntegerField(blank=True, null=True)),
                ('international', models.BooleanField(blank=True, null=True)),
                ('typedocument', models.CharField(blank=True, max_length=3, null=True)),
                ('documentaffiliate', models.CharField(blank=True, max_length=20, null=True)),
                ('fiscalvoucher', models.CharField(blank=True, max_length=100, null=True)),
                ('billerid', models.BigIntegerField(blank=True, null=True)),
                ('recipe', models.IntegerField(blank=True, null=True)),
                ('formuladate', models.DateField(blank=True, null=True)),
                ('freightnumber', models.IntegerField(blank=True, null=True)),
                ('freightcost', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('routeid', models.IntegerField(blank=True, null=True)),
                ('transporterid', models.BigIntegerField(blank=True, null=True)),
                ('timedelivery', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('printedletter', models.BooleanField(blank=True, null=True)),
                ('statewms', models.CharField(blank=True, max_length=1, null=True)),
                ('numberidpre', models.IntegerField(blank=True, null=True)),
                ('locationidpre', models.IntegerField(blank=True, null=True)),
                ('turnsale', models.IntegerField(blank=True, null=True)),
                ('island', models.IntegerField(blank=True, null=True)),
                ('repetitive', models.BooleanField(blank=True, null=True)),
                ('periods', models.IntegerField(blank=True, null=True)),
                ('executed', models.IntegerField(blank=True, null=True)),
                ('quotacopayment', models.BooleanField(blank=True, null=True)),
                ('tariff', models.CharField(blank=True, max_length=1, null=True)),
                ('copaymentpercentage', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('quotacopaymentdiscriminate', models.BooleanField(blank=True, null=True)),
                ('diagnosticid', models.CharField(blank=True, max_length=9, null=True)),
                ('doctorid', models.BigIntegerField(blank=True, db_column='doctorid', null=True)),
                ('passyear', models.BooleanField(blank=True, null=True)),
                ('changeyear', models.BooleanField(blank=True, null=True)),
                ('synchronized', models.BooleanField(blank=True, null=True)),
                ('codeaccumulate', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('reference1', models.CharField(blank=True, max_length=50, null=True)),
                ('reference2', models.CharField(blank=True, max_length=50, null=True)),
                ('domicile', models.BooleanField(blank=True, null=True)),
                ('responsibleid', models.BigIntegerField(blank=True, null=True)),
                ('quotationid', models.IntegerField(blank=True, null=True)),
                ('orderid', models.IntegerField(blank=True, null=True)),
                ('contractid', models.IntegerField(blank=True, null=True)),
                ('contractlocationid', models.IntegerField(blank=True, null=True)),
                ('invoiceid', models.IntegerField(blank=True, null=True)),
                ('locationuseid', models.IntegerField(blank=True, null=True)),
                ('initialdate', models.DateField(blank=True, null=True)),
                ('finaldate', models.DateField(blank=True, null=True)),
                ('plancontract', models.IntegerField(blank=True, null=True)),
                ('policy', models.CharField(blank=True, max_length=10, null=True)),
                ('copayment', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('commission', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('receipt', models.IntegerField(blank=True, null=True)),
                ('highcost', models.BooleanField(blank=True, null=True)),
                ('health', models.BooleanField(blank=True, null=True)),
                ('contractcapited', models.IntegerField(blank=True, null=True)),
                ('sinister', models.IntegerField(blank=True, null=True)),
                ('invoicedate', models.DateField(blank=True, null=True)),
                ('retainpayment', models.BooleanField(blank=True, null=True)),
                ('invoicechar', models.CharField(blank=True, max_length=15, null=True)),
                ('checknumber', models.IntegerField(blank=True, null=True)),
                ('fund', models.IntegerField(blank=True, null=True)),
                ('doclocationid', models.IntegerField(blank=True, null=True)),
                ('retentionif', models.BooleanField(blank=True, null=True)),
                ('reconciled', models.BooleanField(blank=True, null=True)),
                ('reconcileddate', models.DateField(blank=True, null=True)),
                ('anticipation', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('anticipationnumberid', models.IntegerField(blank=True, null=True)),
                ('basepromptpayment', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('pricegenerate', models.BooleanField(blank=True, null=True)),
                ('typeliquidation', models.CharField(blank=True, max_length=1, null=True)),
                ('expensevalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('agreement', models.IntegerField(blank=True, null=True)),
                ('agreementlocationid', models.IntegerField(blank=True, null=True)),
                ('provenance', models.CharField(blank=True, max_length=80, null=True)),
                ('program', models.IntegerField(blank=True, null=True)),
                ('basekilo', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('check_operation', models.BooleanField(blank=True, db_column='"Check"', null=True)),
                ('weightbrute', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('destare', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('weightnet', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('amortize', models.IntegerField(blank=True, null=True)),
                ('seal', models.IntegerField(blank=True, null=True)),
                ('reference', models.CharField(blank=True, max_length=20, null=True)),
                ('credit', models.CharField(blank=True, max_length=1, null=True)),
                ('packing', models.BooleanField(blank=True, null=True)),
                ('lotid', models.CharField(blank=True, max_length=20, null=True)),
                ('documentexpense', models.IntegerField(blank=True, null=True)),
                ('costcenterid', models.IntegerField(blank=True, null=True)),
                ('received', models.BooleanField(blank=True, null=True)),
                ('backorder', models.BooleanField(blank=True, null=True)),
                ('translationdirect', models.BooleanField(blank=True, null=True)),
                ('deliverydate', models.DateField(blank=True, null=True)),
                ('payfreight', models.BooleanField(blank=True, null=True)),
                ('deliverydatemax', models.DateField(blank=True, null=True)),
                ('priority', models.IntegerField(blank=True, null=True)),
                ('consolidated', models.BooleanField(blank=True, null=True)),
                ('dispatch', models.BooleanField(blank=True, null=True)),
                ('dispatchpercentage', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('dispatchvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('separatevalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('separate', models.BooleanField(blank=True, null=True)),
                ('liberation', models.BigIntegerField(blank=True, null=True)),
                ('commercial', models.CharField(blank=True, max_length=1, null=True)),
                ('liberationcommercial', models.BigIntegerField(blank=True, null=True)),
                ('sfa', models.BooleanField(blank=True, null=True)),
                ('consignment', models.BooleanField(blank=True, null=True)),
                ('billingdate', models.DateField(blank=True, null=True)),
                ('fattenig', models.BooleanField(blank=True, null=True)),
                ('picking', models.BooleanField(blank=True, null=True)),
                ('edi', models.BooleanField(blank=True, null=True)),
                ('surety', models.BooleanField(blank=True, null=True)),
                ('suretyexecute', models.BooleanField(blank=True, null=True)),
                ('suretyvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('prorogation', models.DateField(blank=True, null=True)),
                ('daysdelivery', models.IntegerField(blank=True, null=True)),
                ('daysdeliverychar', models.CharField(blank=True, max_length=100, null=True)),
                ('transact', models.DateField(blank=True, null=True)),
                ('budgeting', models.BooleanField(blank=True, null=True)),
                ('entryid', models.BigIntegerField(blank=True, null=True)),
                ('devolutiondate', models.DateField(blank=True, null=True)),
                ('typedelivery', models.CharField(blank=True, max_length=1, null=True)),
                ('bankid', models.IntegerField(blank=True, null=True)),
                ('lettercredit', models.CharField(blank=True, max_length=20, null=True)),
                ('estimated', models.BooleanField(blank=True, null=True)),
                ('verbalacceptance', models.BooleanField(blank=True, null=True)),
                ('authorizeexpense', models.BigIntegerField(blank=True, null=True)),
                ('surveyorid', models.BigIntegerField(blank=True, null=True)),
                ('approves', models.BooleanField(blank=True, null=True)),
                ('accumulate', models.BooleanField(blank=True, null=True)),
                ('approbationdate', models.DateField(blank=True, null=True)),
                ('approbacionby', models.BigIntegerField(blank=True, null=True)),
                ('themeid', models.IntegerField(blank=True, null=True)),
                ('formstart', models.IntegerField(blank=True, null=True)),
                ('applicantid', models.BigIntegerField(blank=True, null=True)),
                ('userid', models.IntegerField(blank=True, null=True)),
                ('incoterms', models.CharField(blank=True, max_length=3, null=True)),
                ('employeeid', models.BigIntegerField(blank=True, null=True)),
                ('guarantee', models.DateField(blank=True, null=True)),
                ('representativeid', models.BigIntegerField(blank=True, null=True)),
                ('purchaseorder', models.CharField(blank=True, max_length=20, null=True)),
                ('periodtype', models.CharField(blank=True, max_length=1, null=True)),
                ('duration', models.IntegerField(blank=True, null=True)),
                ('template', models.IntegerField(blank=True, null=True)),
                ('upc', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('upcpercentage', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('upcaffiliate', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('costadministration', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('sanction', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('otherif', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('coverage', models.CharField(blank=True, max_length=100, null=True)),
                ('assurerid', models.BigIntegerField(blank=True, null=True)),
                ('assured', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('validitypolicy', models.DateField(blank=True, null=True)),
                ('delivery', models.DateField(blank=True, null=True)),
                ('lastinvoice', models.DateField(blank=True, null=True)),
                ('nextinvoice', models.DateField(blank=True, null=True)),
                ('validatesaffiliate', models.BooleanField(blank=True, null=True)),
                ('typecontract', models.CharField(blank=True, max_length=1, null=True)),
                ('cyclebilling', models.CharField(blank=True, max_length=1, null=True)),
                ('renovation', models.CharField(blank=True, max_length=1, null=True)),
                ('increment', models.CharField(blank=True, db_column='"Increment"', max_length=1, null=True)),
                ('incrementvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('renews', models.CharField(blank=True, max_length=1, null=True)),
                ('currency', models.CharField(blank=True, max_length=1, null=True)),
                ('formalitycontract', models.CharField(blank=True, max_length=1, null=True)),
                ('affiliates', models.IntegerField(blank=True, null=True)),
                ('tariffupc', models.IntegerField(blank=True, null=True)),
                ('requirement', models.BigIntegerField(blank=True, null=True)),
                ('forminitiation', models.IntegerField(blank=True, null=True)),
                ('expenseresponsibleid', models.BigIntegerField(blank=True, null=True)),
                ('subscription', models.DateField(blank=True, null=True)),
                ('printed', models.BooleanField(blank=True, null=True)),
                ('mark', models.BooleanField(blank=True, null=True)),
                ('status', models.CharField(blank=True, max_length=1, null=True)),
                ('state', models.CharField(blank=True, max_length=1, null=True)),
                ('updated', models.DateField(blank=True, null=True)),
                ('locationid1', models.IntegerField(blank=True, null=True)),
                ('contactid', models.BigIntegerField(blank=True, null=True)),
                ('typecontractid', models.IntegerField(blank=True, null=True)),
                ('typetransportid', models.IntegerField(blank=True, null=True)),
                ('countryoriginid', models.IntegerField(blank=True, null=True)),
                ('expiration', models.DateField(blank=True, null=True)),
                ('numbercontract', models.IntegerField(blank=True, null=True)),
                ('locationidcontract', models.IntegerField(blank=True, null=True)),
                ('classificationid', models.BigIntegerField(blank=True, null=True)),
                ('type', models.CharField(blank=True, max_length=1, null=True)),
                ('attention', models.BooleanField(blank=True, null=True)),
                ('responsableid', models.BigIntegerField(blank=True, null=True)),
                ('providerid', models.BigIntegerField(blank=True, null=True)),
                ('diagnostic', models.CharField(blank=True, max_length=9, null=True)),
                ('diagnostic1', models.CharField(blank=True, max_length=9, null=True)),
                ('diagnostic2', models.CharField(blank=True, max_length=9, null=True)),
                ('diagnostic3', models.CharField(blank=True, max_length=9, null=True)),
                ('impute', models.CharField(blank=True, max_length=1, null=True)),
                ('valueimpute', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('class_field', models.CharField(blank=True, db_column='class', max_length=1, null=True)),
                ('programid', models.IntegerField(blank=True, null=True)),
                ('typesolicitude', models.CharField(blank=True, max_length=1, null=True)),
                ('locationsolicitude', models.CharField(blank=True, max_length=1, null=True)),
                ('servicesolicitude', models.CharField(blank=True, max_length=40, null=True)),
                ('numbersolicitude', models.IntegerField(blank=True, null=True)),
                ('datesolicitude', models.DateField(blank=True, null=True)),
                ('hoursolicitude', models.DateField(blank=True, null=True)),
                ('dateacttutelage', models.DateField(blank=True, null=True)),
                ('authorizationmanual', models.BigIntegerField(blank=True, null=True)),
                ('copaymentmanual', models.IntegerField(blank=True, null=True)),
                ('justificationid', models.IntegerField(blank=True, null=True)),
                ('alternatetiveid1', models.IntegerField(blank=True, null=True)),
                ('alternatetiveid2', models.IntegerField(blank=True, null=True)),
                ('alternatetiveid3', models.IntegerField(blank=True, null=True)),
                ('alternatetiveid4', models.IntegerField(blank=True, null=True)),
                ('modalitycon', models.CharField(blank=True, max_length=2, null=True)),
                ('sinisterid', models.IntegerField(blank=True, null=True)),
                ('typeorigin', models.CharField(blank=True, max_length=1, null=True)),
                ('typepriority', models.CharField(blank=True, max_length=1, null=True)),
                ('formpost', models.CharField(blank=True, max_length=1, null=True)),
                ('shipping', models.DateField(blank=True, null=True)),
                ('shippingentity', models.DateField(blank=True, null=True)),
                ('bill', models.CharField(blank=True, max_length=17, null=True)),
                ('web', models.CharField(blank=True, max_length=1, null=True)),
                ('stateaffiliate', models.CharField(blank=True, max_length=2, null=True)),
                ('typedoctorid', models.IntegerField(blank=True, null=True)),
                ('contractgloss', models.IntegerField(blank=True, null=True)),
                ('typeaffdoctorid', models.IntegerField(blank=True, null=True)),
                ('docdoctor', models.BigIntegerField(blank=True, null=True)),
                ('typedocumentiddoctor', models.CharField(blank=True, max_length=2, null=True)),
                ('statebdua', models.CharField(blank=True, max_length=2, null=True)),
                ('levelsisben', models.IntegerField(blank=True, null=True)),
                ('numbersolicitudeoasis', models.BigIntegerField(blank=True, null=True)),
                ('anticipate', models.BooleanField(blank=True, null=True)),
                ('dateorder', models.DateField(blank=True, null=True)),
                ('filingorder', models.DateField(blank=True, null=True)),
                ('regimen', models.CharField(blank=True, max_length=1, null=True)),
                ('levelcontributory', models.IntegerField(blank=True, null=True)),
                ('concurrence', models.BooleanField(blank=True, null=True)),
                ('filing', models.DateField(blank=True, null=True)),
                ('locationprovider', models.IntegerField(blank=True, null=True)),
                ('confirmby', models.BigIntegerField(blank=True, null=True)),
                ('age', models.CharField(blank=True, max_length=30, null=True)),
                ('dateprovision', models.DateField(blank=True, null=True)),
                ('valuebill', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('geographiclocationid', models.IntegerField(blank=True, null=True)),
                ('ingress', models.DateField(blank=True, null=True)),
                ('originattention', models.CharField(blank=True, max_length=1, null=True)),
                ('typeservice', models.CharField(blank=True, max_length=1, null=True)),
                ('priorityattention', models.CharField(blank=True, max_length=1, null=True)),
                ('typelocationaffiliate', models.CharField(blank=True, max_length=1, null=True)),
                ('codeservice', models.IntegerField(blank=True, null=True)),
                ('subspeciality', models.IntegerField(blank=True, null=True)),
                ('numberbed', models.CharField(blank=True, max_length=20, null=True)),
                ('justificationclinic', models.CharField(blank=True, max_length=1000, null=True)),
                ('documentapplicantid', models.BigIntegerField(blank=True, null=True)),
                ('nameapplicantid', models.CharField(blank=True, max_length=200, null=True)),
                ('phone', models.CharField(blank=True, max_length=100, null=True)),
                ('placeactivity', models.CharField(blank=True, max_length=500, null=True)),
                ('source', models.CharField(blank=True, max_length=1, null=True)),
                ('motive', models.CharField(blank=True, max_length=1000, null=True)),
                ('typeuser', models.CharField(blank=True, max_length=1, null=True)),
                ('notification', models.DateField(blank=True, null=True)),
                ('automatic', models.BooleanField(blank=True, null=True)),
                ('doctor', models.CharField(blank=True, max_length=100, null=True)),
                ('placedoctor', models.CharField(blank=True, max_length=100, null=True)),
                ('motiveannulationid', models.IntegerField(blank=True, null=True)),
                ('sonof', models.BooleanField(blank=True, null=True)),
                ('year', models.IntegerField(blank=True, null=True)),
                ('filed', models.DateField(blank=True, null=True)),
                ('record', models.CharField(blank=True, max_length=20, null=True)),
                ('history', models.CharField(blank=True, max_length=20, null=True)),
                ('ambit', models.CharField(blank=True, max_length=1, null=True)),
                ('objective', models.CharField(blank=True, max_length=1, null=True)),
                ('negation', models.IntegerField(blank=True, null=True)),
                ('locationnegation', models.IntegerField(blank=True, null=True)),
                ('specialidadid', models.IntegerField(blank=True, null=True)),
                ('letterentity', models.BooleanField(blank=True, null=True)),
                ('alfanet', models.BigIntegerField(blank=True, null=True)),
                ('datealfanet', models.DateField(blank=True, null=True)),
                ('datemeeting', models.DateField(blank=True, null=True)),
                ('presolicitude', models.IntegerField(blank=True, null=True)),
                ('locationpresolicitude', models.IntegerField(blank=True, null=True)),
                ('clientideps', models.BigIntegerField(blank=True, null=True)),
                ('clientidips', models.BigIntegerField(blank=True, null=True)),
                ('clientiduser', models.BigIntegerField(blank=True, null=True)),
                ('accepted', models.BooleanField(blank=True, null=True)),
                ('docdocumentid', models.IntegerField(blank=True, null=True)),
                ('meeting', models.IntegerField(blank=True, null=True)),
                ('assessorid', models.BigIntegerField(blank=True, null=True)),
                ('clientidsolicitude', models.BigIntegerField(blank=True, null=True)),
                ('ambitsolicitude', models.CharField(blank=True, max_length=1, null=True)),
                ('numberapprobation', models.IntegerField(blank=True, null=True)),
                ('recovery', models.CharField(blank=True, max_length=20, null=True)),
                ('actioning', models.CharField(blank=True, max_length=100, null=True)),
                ('actioned', models.CharField(blank=True, max_length=1, null=True)),
                ('impugn', models.CharField(blank=True, max_length=1, null=True)),
                ('judgedid', models.IntegerField(blank=True, null=True)),
                ('file', models.IntegerField(blank=True, db_column='"File"', null=True)),
                ('judgement', models.DateField(blank=True, null=True)),
                ('integral', models.BooleanField(blank=True, null=True)),
                ('ctc', models.BooleanField(blank=True, null=True)),
                ('pretensionid', models.IntegerField(blank=True, null=True)),
                ('typedocumentidactioning', models.CharField(blank=True, max_length=2, null=True)),
                ('docactioning', models.CharField(blank=True, max_length=20, null=True)),
                ('nameactioning', models.CharField(blank=True, max_length=100, null=True)),
                ('revoked', models.BooleanField(blank=True, null=True)),
                ('provisional', models.BooleanField(blank=True, null=True)),
                ('deliverysuccessive', models.BooleanField(blank=True, null=True)),
                ('pos', models.BooleanField(blank=True, null=True)),
                ('days', models.IntegerField(blank=True, null=True)),
                ('docnegation', models.CharField(blank=True, max_length=2, null=True)),
                ('dateauto', models.DateField(blank=True, null=True)),
                ('numberjudgement', models.BigIntegerField(blank=True, null=True)),
                ('datesinister', models.DateField(blank=True, null=True)),
                ('policyid', models.IntegerField(blank=True, null=True)),
                ('aviso', models.BooleanField(blank=True, null=True)),
                ('dateaviso', models.DateField(blank=True, null=True)),
                ('numberaviso', models.IntegerField(blank=True, null=True)),
                ('bills', models.IntegerField(blank=True, null=True)),
                ('stateevent', models.CharField(blank=True, max_length=2, null=True)),
                ('deductible', models.BooleanField(blank=True, null=True)),
                ('gloss', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('notapplicable', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('glosssure', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('recovered', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('valuedeductible', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('recover', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('datereport', models.DateField(blank=True, null=True)),
                ('datebirth', models.DateField(blank=True, null=True)),
                ('viaingress', models.CharField(blank=True, max_length=1, null=True)),
                ('houringress', models.DateField(blank=True, null=True)),
                ('parturitioncaesarean', models.BooleanField(blank=True, null=True)),
                ('documentbill', models.CharField(blank=True, max_length=3, null=True)),
                ('numberbill', models.IntegerField(blank=True, null=True)),
                ('locationbill', models.IntegerField(blank=True, null=True)),
                ('quantitydays', models.IntegerField(blank=True, null=True)),
                ('egress', models.DateField(blank=True, null=True)),
                ('typedocumentidresponsable', models.CharField(blank=True, max_length=2, null=True)),
                ('documentidresponsable', models.CharField(blank=True, max_length=20, null=True)),
                ('nameresponsable', models.CharField(blank=True, max_length=200, null=True)),
                ('addressresponsable', models.CharField(blank=True, max_length=100, null=True)),
                ('phoneresponsable', models.CharField(blank=True, max_length=30, null=True)),
                ('geolocationidresponsable', models.IntegerField(blank=True, null=True)),
                ('nameprofessional', models.CharField(blank=True, max_length=20, null=True)),
                ('cellularprofessional', models.CharField(blank=True, max_length=20, null=True)),
                ('phoneprofessional', models.CharField(blank=True, max_length=20, null=True)),
                ('serviceorigin', models.BigIntegerField(blank=True, null=True)),
                ('servicesolicited', models.BigIntegerField(blank=True, null=True)),
                ('typeambulance', models.CharField(blank=True, max_length=1, null=True)),
                ('typetranslation', models.CharField(blank=True, max_length=1, null=True)),
                ('dateambulance', models.DateField(blank=True, null=True)),
                ('dateclose', models.DateField(blank=True, null=True)),
                ('hourclose', models.DateField(blank=True, null=True)),
                ('numberattention', models.IntegerField(blank=True, null=True)),
                ('triage', models.CharField(blank=True, max_length=1, null=True)),
                ('remission', models.BooleanField(blank=True, null=True)),
                ('nameips', models.CharField(blank=True, max_length=60, null=True)),
                ('codehabipsremission', models.CharField(blank=True, max_length=12, null=True)),
                ('locationipsremission', models.IntegerField(blank=True, null=True)),
                ('destination', models.CharField(blank=True, max_length=2, null=True)),
                ('nameinformant', models.CharField(blank=True, max_length=40, null=True)),
                ('placeinformant', models.CharField(blank=True, max_length=50, null=True)),
                ('phoneinformant', models.CharField(blank=True, max_length=30, null=True)),
                ('cellularinformant', models.CharField(blank=True, max_length=30, null=True)),
                ('registerby', models.BigIntegerField(blank=True, null=True)),
                ('nameregister', models.CharField(blank=True, max_length=40, null=True)),
                ('docnumberid', models.BigIntegerField(blank=True, null=True)),
                ('markpre', models.CharField(blank=True, max_length=1, null=True)),
                ('analysis', models.CharField(blank=True, max_length=4000, null=True)),
                ('approbation', models.CharField(blank=True, max_length=4000, null=True)),
                ('description', models.CharField(blank=True, max_length=4000, null=True)),
                ('justification', models.CharField(blank=True, max_length=4000, null=True)),
                ('observation', models.CharField(blank=True, max_length=4000, null=True)),
                ('resume', models.CharField(blank=True, max_length=4000, null=True)),
                ('textapplicant', models.CharField(blank=True, max_length=4000, null=True)),
                ('textapprobation', models.CharField(blank=True, max_length=4000, null=True)),
                ('formula', models.CharField(blank=True, max_length=20, null=True)),
                ('remissioninvoice', models.CharField(blank=True, max_length=1, null=True)),
                ('typedocumentid', models.CharField(blank=True, max_length=2, null=True)),
                ('clientcode', models.CharField(blank=True, max_length=20, null=True)),
                ('firstlastname', models.CharField(blank=True, max_length=40, null=True)),
                ('secondlastname', models.CharField(blank=True, max_length=30, null=True)),
                ('firstfirstname', models.CharField(blank=True, max_length=40, null=True)),
                ('secondfirstname', models.CharField(blank=True, max_length=30, null=True)),
                ('birthdate', models.DateField(blank=True, null=True)),
                ('finaldate1', models.DateField(blank=True, null=True)),
                ('upcaffiliate1', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('affiliates1', models.IntegerField(blank=True, null=True)),
                ('total1', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('bl', models.CharField(blank=True, max_length=50, null=True)),
                ('containers', models.IntegerField(blank=True, null=True)),
                ('countrydestinyid', models.IntegerField(blank=True, null=True)),
                ('countrypurchaseid', models.IntegerField(blank=True, null=True)),
                ('countryshipmentid', models.IntegerField(blank=True, null=True)),
                ('customsid', models.IntegerField(blank=True, null=True)),
                ('datearrival', models.DateField(blank=True, null=True)),
                ('datebl', models.DateField(blank=True, null=True)),
                ('incotermsid', models.CharField(blank=True, max_length=3, null=True)),
                ('lines', models.IntegerField(blank=True, null=True)),
                ('packages', models.IntegerField(blank=True, null=True)),
                ('portdestiny', models.CharField(blank=True, max_length=50, null=True)),
                ('portshipment', models.CharField(blank=True, max_length=50, null=True)),
                ('vessel', models.CharField(blank=True, max_length=50, null=True)),
                ('equipmentid', models.CharField(blank=True, max_length=20, null=True)),
                ('conductorid', models.BigIntegerField(blank=True, null=True)),
                ('assistantid', models.BigIntegerField(blank=True, null=True)),
                ('guide', models.BigIntegerField(blank=True, null=True)),
                ('weighttare', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('weightloaded', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('counterinitial', models.IntegerField(blank=True, null=True)),
                ('counterfinal', models.IntegerField(blank=True, null=True)),
                ('counter', models.IntegerField(blank=True, null=True)),
                ('stop', models.BooleanField(blank=True, null=True)),
                ('failureid', models.IntegerField(blank=True, null=True)),
                ('causeid', models.IntegerField(blank=True, null=True)),
                ('actionid', models.IntegerField(blank=True, null=True)),
                ('subject', models.CharField(blank=True, max_length=4000, null=True)),
                ('time', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('daterequired', models.DateField(blank=True, null=True)),
                ('hourrequired', models.DateField(blank=True, null=True)),
                ('billto', models.CharField(blank=True, max_length=1, null=True)),
                ('qualification', models.CharField(blank=True, max_length=1, null=True)),
                ('typeoperationid', models.IntegerField(blank=True, null=True)),
                ('lineid', models.IntegerField(blank=True, null=True)),
                ('initialhour', models.DateField(blank=True, null=True)),
                ('finalhour', models.DateField(blank=True, null=True)),
                ('turn', models.IntegerField(blank=True, null=True)),
                ('packingwms', models.BooleanField(blank=True, null=True)),
                ('contractdocumentid', models.CharField(blank=True, max_length=3, null=True)),
                ('priority1', models.IntegerField(blank=True, null=True)),
                ('sourceid', models.IntegerField(blank=True, null=True)),
                ('dateincapacity', models.DateField(blank=True, null=True)),
                ('dateparturition', models.DateField(blank=True, null=True)),
                ('parturitionmultiple', models.BooleanField(blank=True, null=True)),
                ('weeks', models.IntegerField(blank=True, null=True)),
                ('dateaccident', models.DateField(blank=True, null=True)),
                ('isprorogation', models.BooleanField(blank=True, null=True)),
                ('overlap', models.BooleanField(blank=True, null=True)),
                ('hospitalization', models.BooleanField(blank=True, null=True)),
                ('requirements', models.BooleanField(blank=True, null=True)),
                ('dayspayment', models.IntegerField(blank=True, null=True)),
                ('datepayment', models.DateField(blank=True, null=True)),
                ('sample', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('drift1', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('drift2', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('almondsan', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('gramspasilla', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('gramsbroca', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('productid', models.BigIntegerField(blank=True, null=True)),
                ('associate', models.BooleanField(blank=True, null=True)),
                ('quantity1', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('resourceid', models.BigIntegerField(blank=True, null=True)),
                ('updatedby', models.IntegerField(blank=True, null=True)),
                ('quantityslime', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('paymentid', models.BigIntegerField(blank=True, null=True)),
                ('localizationid', models.CharField(blank=True, max_length=20, null=True)),
                ('xml', models.BinaryField(blank=True, null=True)),
                ('xmlname', models.CharField(blank=True, max_length=100, null=True)),
                ('status1', models.CharField(blank=True, max_length=1, null=True)),
                ('presales', models.BigIntegerField(blank=True, null=True)),
                ('documentidbudget', models.CharField(blank=True, max_length=3, null=True)),
                ('numberidbudget', models.IntegerField(blank=True, null=True)),
                ('locationidbudget', models.IntegerField(blank=True, null=True)),
                ('budgetyearpass', models.BooleanField(blank=True, null=True)),
                ('budgetyearchanged', models.BooleanField(blank=True, null=True)),
                ('overexecuted', models.CharField(blank=True, max_length=1, null=True)),
                ('contractidfiled', models.BigIntegerField(blank=True, null=True)),
                ('docdocumentcid', models.CharField(blank=True, max_length=3, null=True)),
                ('approbationreceivablehourlocal', models.DateField(blank=True, null=True)),
                ('approbationcomercialhourlocal', models.DateField(blank=True, null=True)),
                ('productid1', models.BigIntegerField(blank=True, null=True)),
                ('productid2', models.BigIntegerField(blank=True, null=True)),
                ('productid3', models.BigIntegerField(blank=True, null=True)),
                ('emailprofessional', models.CharField(blank=True, max_length=50, null=True)),
                ('modetranslation', models.CharField(blank=True, max_length=1, null=True)),
                ('public', models.BooleanField(blank=True, db_column='"Public"', null=True)),
                ('sequestration', models.BooleanField(blank=True, null=True)),
                ('translape', models.BooleanField(blank=True, null=True)),
                ('daysprorogation', models.IntegerField(blank=True, null=True)),
                ('cashonly', models.BooleanField(blank=True, null=True)),
                ('transporterfreight', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('license', models.IntegerField(blank=True, null=True)),
                ('cdp', models.IntegerField(blank=True, null=True)),
                ('planningweek', models.IntegerField(blank=True, null=True)),
            ],
            options={
                'db_table': 'operation',
                'managed': False,
            },
        ),
    ]
