# Generated by Django 4.1.5 on 2023-02-02 01:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0004_account_vaccountingbalanceclient'),
    ]

    operations = [
        migrations.DeleteModel(
            name='VAccountingBalanceClient',
        ),
        migrations.AddConstraint(
            model_name='company',
            constraint=models.UniqueConstraint(fields=('company_id',), name='UNQ_company_company_id'),
        ),
    ]
