# Generated by Django 4.1.7 on 2023-03-07 16:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0015_statemachine_update_oasis'),
    ]

    operations = [
        migrations.AddField(
            model_name='statemachine',
            name='is_changed',
            field=models.BooleanField(default=False, verbose_name='Validate changes'),
        ),
        migrations.AddField(
            model_name='statemachine',
            name='timeout',
            field=models.IntegerField(default=0, verbose_name='Timeout (hours)'),
        ),
    ]
