# Generated by Django 4.1.5 on 2023-02-07 02:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0006_periods'),
    ]

    operations = [
        migrations.CreateModel(
            name='Cycle',
            fields=[
                ('companyid', models.IntegerField(primary_key=True, serialize=False)),
                ('type', models.CharField(max_length=1)),
                ('number', models.IntegerField(db_column='"Number"')),
                ('year', models.IntegerField()),
                ('period', models.IntegerField()),
                ('periodyear', models.IntegerField()),
                ('updated', models.DateField(blank=True, null=True)),
                ('updatedby', models.IntegerField(blank=True, null=True)),
            ],
            options={
                'db_table': 'cycle',
                'managed': False,
            },
        ),
    ]
