# Generated by Django 4.1.7 on 2023-03-07 16:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0016_statemachine_is_changed_statemachine_timeout'),
    ]

    operations = [
        migrations.AddField(
            model_name='statemachine',
            name='state_at_timeout',
            field=models.IntegerField(blank=True, choices=[(0, 'New'), (1, 'Changed'), (2, 'Signed'), (3, 'Partial'), (4, 'Finished'), (9, 'Rejected')], null=True, verbose_name='State at timeout'),
        ),
    ]
