# Generated by Django 4.1.7 on 2023-03-06 20:01

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0012_offer_price'),
    ]

    operations = [
        migrations.AddField(
            model_name='statemachine',
            name='is_final',
            field=models.BooleanField(default=False, verbose_name='Is final state'),
        ),
        migrations.AddField(
            model_name='statemachine',
            name='is_initial',
            field=models.BooleanField(default=False, verbose_name='Is initial state'),
        ),
        migrations.AlterField(
            model_name='offer',
            name='status',
            field=models.IntegerField(choices=[(0, 'New'), (1, 'Changed'), (2, 'Signed'), (3, 'Partial'), (4, 'Finished'), (9, 'Rejected')], default=0, verbose_name='Status'),
        ),
        migrations.AlterField(
            model_name='offer',
            name='warehouse',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_query_name='warehouse', to='oasis.coffeewarehouse', verbose_name='Warehouse'),
        ),
        migrations.AlterField(
            model_name='statemachine',
            name='from_state',
            field=models.IntegerField(blank=True, choices=[(0, 'New'), (1, 'Changed'), (2, 'Signed'), (3, 'Partial'), (4, 'Finished'), (9, 'Rejected')], null=True, verbose_name='From State'),
        ),
        migrations.AlterField(
            model_name='statemachine',
            name='state',
            field=models.IntegerField(choices=[(0, 'New'), (1, 'Changed'), (2, 'Signed'), (3, 'Partial'), (4, 'Finished'), (9, 'Rejected')], default=0, verbose_name='State'),
        ),
    ]
