# Generated by Django 4.1.7 on 2023-03-07 08:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0014_remove_statemachine_unq_coffeeoffer_statemachine_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='statemachine',
            name='update_oasis',
            field=models.BooleanField(default=False, verbose_name='Update Oasis'),
        ),
    ]
