# Generated by Django 4.1.7 on 2023-03-16 21:38

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0017_statemachine_state_at_timeout'),
    ]

    operations = [
        migrations.CreateModel(
            name='OfferMov',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('modified_at', models.DateTimeField(auto_now=True, verbose_name='Modified at')),
                ('status', models.IntegerField(choices=[(0, 'New'), (1, 'Changed'), (2, 'Signed'), (3, 'Partial'), (4, 'Finished'), (9, 'Rejected')])),
                ('delivery_date', models.DateField(blank=True, null=True)),
                ('price', models.DecimalField(blank=True, decimal_places=2, max_digits=7, null=True)),
                ('kg_offered', models.DecimalField(blank=True, decimal_places=2, max_digits=9, null=True)),
                ('kg_received', models.DecimalField(blank=True, decimal_places=2, max_digits=9, null=True)),
                ('created', models.BooleanField(default=False)),
                ('offer', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='offer_movements', related_query_name='offer', to='oasis.offer')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
