# Generated by Django 4.1.7 on 2023-03-07 08:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0013_statemachine_is_final_statemachine_is_initial_and_more'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='statemachine',
            name='UNQ_CoffeeOffer_StateMachine',
        ),
        migrations.AddField(
            model_name='statemachine',
            name='send_contract',
            field=models.BooleanField(default=False, verbose_name='Send contract'),
        ),
        migrations.AddConstraint(
            model_name='statemachine',
            constraint=models.UniqueConstraint(fields=('state', 'from_state', 'oasis_state', 'oasis_status'), name='UNQ_CoffeeOffer_StateMachine'),
        ),
    ]
