# Generated by Django 4.1.7 on 2023-03-04 03:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0011_offer_statemachine_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='offer',
            name='price',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=7, verbose_name='Price'),
        ),
    ]
