# Generated by Django 4.1.7 on 2023-03-01 16:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0008_location_coffeewarehouse_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Associatebalance',
            fields=[
                ('companyid', models.IntegerField(primary_key=True, serialize=False)),
                ('period', models.IntegerField()),
                ('year', models.IntegerField()),
                ('clientid', models.BigIntegerField()),
                ('contributionvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('contributionyearvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('contributiontotalvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('salesvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('receivablesexpiredvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('otherexpiredvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('anticipationexpiredvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('contribution', models.BooleanField(blank=True, null=True)),
                ('contributionyear', models.BooleanField(blank=True, null=True)),
                ('sales', models.BooleanField(blank=True, null=True)),
                ('receivablesexpired', models.BooleanField(blank=True, null=True)),
                ('otherexpired', models.BooleanField(blank=True, null=True)),
                ('anticipationexpired', models.BooleanField(blank=True, null=True)),
                ('able', models.BooleanField(blank=True, null=True)),
                ('cosigner', models.BooleanField(blank=True, null=True)),
                ('purchasefuture', models.BooleanField(blank=True, null=True)),
                ('kiloscoffeegreen', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('almondsound', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('almonddefect', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('areacoffeetotal', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('areacoffeeproductive', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('contributionbalance', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('assembly', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('revaluation', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('solidarity', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('contributionbalancepay', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('observation', models.CharField(blank=True, max_length=4000, null=True)),
                ('billing', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
            ],
            options={
                'db_table': 'associatebalance',
                'managed': False,
            },
        ),
    ]
