{% load i18n %}
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Title</title>
</head>
<body>
<p>{% translate "Hello" %}, {{ customer_name }}</p>
<p>{% blocktranslate %}Thank you for use the <strong>CADEFIHUILA's</strong> transactional portal. To confirm that you´re sending an offer of coffee sale and sign it, please write the below code at the form of web page.{% endblocktranslate %}</p>
<p>
    <h2 style="text-align: center;">{{ customer_code }}</h2>
</p>
<p>{% blocktranslate %}The code is valid for {{ code_timeout }} minutes.{% endblocktranslate %}</p>
<p>{% blocktranslate %}Keep in mind that signing this offer through digital media such as this obliges you to comply with it in accordance with the provisions of article 846 of the Commercial Code.{% endblocktranslate %}
</p>
<p>
    <label style="font-size: 8px;">
        {% blocktranslate %}This email was generated automatically at {{ email_datetime }} with id {{ email_id }}. Please do not answer it.{% endblocktranslate %}
    </label>
</p>
</body>
</html>