# Generated by Django 4.1.5 on 2023-02-05 00:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0005_delete_vaccountingbalanceclient_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Periods',
            fields=[
                ('companyid', models.IntegerField(primary_key=True, serialize=False)),
                ('year', models.IntegerField()),
                ('period', models.IntegerField()),
                ('final', models.DateField(blank=True, null=True)),
                ('open', models.BooleanField(blank=True, null=True)),
                ('plan', models.IntegerField()),
                ('weeks', models.IntegerField(blank=True, null=True)),
                ('fiscalperiod', models.IntegerField(blank=True, null=True)),
                ('fiscalyear', models.IntegerField(blank=True, null=True)),
                ('inflation', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('interes', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('budgetperiod', models.IntegerField(blank=True, null=True)),
                ('budgetyear', models.IntegerField(blank=True, null=True)),
                ('updated', models.DateField(blank=True, null=True)),
                ('updatedby', models.IntegerField(blank=True, null=True)),
            ],
            options={
                'db_table': 'periods',
                'managed': False,
            },
        ),
    ]
