# Generated by Django 4.1.5 on 2023-01-26 02:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0002_geographiclocation_typeclient_documenttype_client_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='OasisCompany',
            fields=[
                ('companyid', models.IntegerField(primary_key=True, serialize=False)),
                ('companyname', models.CharField(max_length=100)),
                ('companycode', models.CharField(max_length=30)),
                ('countryid', models.IntegerField()),
                ('clientid', models.BigIntegerField()),
                ('liquidation', models.CharField(blank=True, max_length=1, null=True)),
                ('retentioninvoice', models.BooleanField(blank=True, null=True)),
                ('languageid', models.IntegerField(blank=True, null=True)),
                ('address', models.CharField(blank=True, max_length=100, null=True)),
                ('address1', models.CharField(blank=True, max_length=100, null=True)),
                ('phone', models.CharField(blank=True, max_length=100, null=True)),
                ('city', models.CharField(blank=True, max_length=100, null=True)),
                ('state', models.CharField(blank=True, max_length=100, null=True)),
                ('rounding', models.BooleanField(blank=True, null=True)),
                ('typerounding', models.CharField(blank=True, max_length=1, null=True)),
                ('partialdispatch', models.BooleanField(blank=True, null=True)),
                ('typeprice', models.CharField(blank=True, max_length=1, null=True)),
                ('validatecredit', models.BooleanField(blank=True, null=True)),
                ('discountorder', models.BooleanField(blank=True, null=True)),
                ('discountvolume', models.BooleanField(blank=True, null=True)),
                ('discountlocation', models.BooleanField(blank=True, null=True)),
                ('discountpromptpayment', models.BooleanField(blank=True, null=True)),
                ('creditunit', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('local_check', models.BooleanField(blank=True, db_column='check', null=True)),
                ('local_delay', models.BooleanField(blank=True, db_column='delay', null=True)),
                ('limit', models.BooleanField(blank=True, null=True)),
                ('interest', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('delayinterest', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('sanctioncheck', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('suspensionrate', models.CharField(blank=True, max_length=1, null=True)),
                ('legalrate', models.CharField(blank=True, max_length=1, null=True)),
                ('fiscalperiod', models.IntegerField(blank=True, null=True)),
                ('physical', models.CharField(blank=True, max_length=1, null=True)),
                ('transit', models.BooleanField(blank=True, null=True)),
                ('costmethod', models.CharField(blank=True, max_length=1, null=True)),
                ('costsystem', models.CharField(blank=True, max_length=1, null=True)),
                ('costmodel', models.CharField(blank=True, max_length=1, null=True)),
                ('periodconsumption', models.IntegerField(blank=True, null=True)),
                ('coststore', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('costpurchase', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('receipttolerance', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('margin', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('quotation', models.IntegerField(blank=True, null=True)),
                ('transporter', models.BooleanField(blank=True, null=True)),
                ('risckentity', models.BigIntegerField(blank=True, null=True)),
                ('compensationentity', models.BigIntegerField(blank=True, null=True)),
                ('autoliquidation', models.CharField(blank=True, max_length=1, null=True)),
                ('paymentlocationid', models.IntegerField(blank=True, null=True)),
                ('associatequota', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('locationjournalid', models.IntegerField(blank=True, null=True)),
                ('creditretention', models.BooleanField(blank=True, null=True)),
                ('validatecreditremission', models.BooleanField(blank=True, null=True)),
                ('dispatch', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('approveorder', models.BooleanField(blank=True, null=True)),
                ('budgetquantity', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('budgetvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('changepriceinvoiceorder', models.BooleanField(blank=True, null=True)),
                ('factoradd', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('factorsubstraction', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('supercode', models.CharField(blank=True, max_length=6, null=True)),
                ('pricetypefrequent', models.IntegerField(blank=True, null=True)),
                ('exchangeratevalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('exchangerate', models.BooleanField(blank=True, null=True)),
                ('pricemaximum', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('extcode', models.CharField(blank=True, max_length=13, null=True)),
                ('associateinterest', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('loaninteres', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('programproduction', models.CharField(blank=True, max_length=1, null=True)),
                ('planproduction', models.CharField(blank=True, max_length=1, null=True)),
                ('estandarproduction', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('premiumsupervisor', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('premiumoperator', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('premiumattendant', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('premiumsupervisorsupport', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('premiumassistant', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('attendantid', models.BigIntegerField(blank=True, null=True)),
                ('supervisorsupport', models.BigIntegerField(blank=True, null=True)),
                ('attendantmix', models.BigIntegerField(blank=True, null=True)),
                ('periodsrotation', models.IntegerField(blank=True, null=True)),
                ('cashpaymentid', models.IntegerField(blank=True, null=True)),
                ('dynamicweight', models.BooleanField(blank=True, null=True)),
                ('accountpayroll', models.CharField(blank=True, max_length=1, null=True)),
                ('costproduction', models.CharField(blank=True, max_length=1, null=True)),
                ('methodcommision', models.CharField(blank=True, max_length=1, null=True)),
                ('security', models.BigIntegerField(blank=True, null=True)),
                ('assetorder', models.BooleanField(blank=True, null=True)),
                ('pricefreight', models.BooleanField(blank=True, null=True)),
                ('picking', models.BooleanField(blank=True, null=True)),
                ('localizationabc', models.BooleanField(blank=True, null=True)),
                ('mobile', models.BooleanField(blank=True, null=True)),
                ('receivelocalization', models.CharField(blank=True, max_length=20, null=True)),
                ('dispatchlocalization', models.CharField(blank=True, max_length=20, null=True)),
                ('packinglocalization', models.CharField(blank=True, max_length=20, null=True)),
                ('accounttax', models.BooleanField(blank=True, null=True)),
                ('accounttaxpurchase', models.BooleanField(blank=True, null=True)),
                ('efficiency', models.BooleanField(blank=True, null=True)),
                ('approvedispatch', models.BooleanField(blank=True, null=True)),
                ('matrixid', models.IntegerField(blank=True, null=True)),
                ('generateprice', models.BooleanField(blank=True, null=True)),
                ('comissionsales', models.BooleanField(blank=True, null=True)),
                ('comissioncollection', models.BooleanField(blank=True, null=True)),
                ('comissionbudget', models.BooleanField(blank=True, null=True)),
                ('rolereceivablesid', models.IntegerField(blank=True, null=True)),
                ('rolecommercialid', models.IntegerField(blank=True, null=True)),
                ('validatecommercial', models.BooleanField(blank=True, null=True)),
                ('methodpromptpayment', models.IntegerField(blank=True, null=True)),
                ('discount', models.IntegerField(blank=True, null=True)),
                ('multicompanydistribution', models.BooleanField(blank=True, null=True)),
                ('pricetypedistributor', models.CharField(blank=True, max_length=1, null=True)),
                ('roleproductionid', models.IntegerField(blank=True, null=True)),
                ('taxpurchase', models.CharField(blank=True, max_length=1, null=True)),
                ('taxsales', models.CharField(blank=True, max_length=1, null=True)),
                ('typeproduction', models.CharField(blank=True, max_length=1, null=True)),
                ('presentation', models.BooleanField(blank=True, null=True)),
                ('dispatchcontrol', models.BooleanField(blank=True, null=True)),
                ('bicurrency', models.BooleanField(blank=True, null=True)),
                ('accounttaxexpense', models.BooleanField(blank=True, null=True)),
                ('typecontract', models.CharField(blank=True, max_length=1, null=True)),
                ('quotamoderator', models.BooleanField(blank=True, null=True)),
                ('bondrepurchase', models.BooleanField(blank=True, null=True)),
                ('costcenterinvoice', models.BooleanField(blank=True, null=True)),
                ('projectinvoice', models.BooleanField(blank=True, null=True)),
                ('validateexpirationinvoice', models.BooleanField(blank=True, null=True)),
                ('email', models.CharField(blank=True, max_length=100, null=True)),
                ('validateretentionorder', models.BooleanField(blank=True, null=True)),
                ('initialcash', models.CharField(blank=True, max_length=20, null=True)),
                ('changecash', models.CharField(blank=True, max_length=20, null=True)),
                ('type', models.CharField(blank=True, max_length=20, null=True)),
                ('initialdate', models.CharField(blank=True, max_length=20, null=True)),
                ('finaldate', models.CharField(blank=True, max_length=20, null=True)),
                ('documentrole', models.BooleanField(blank=True, null=True)),
                ('template', models.BooleanField(blank=True, null=True)),
                ('demo', models.BooleanField(blank=True, null=True)),
                ('created', models.DateField(blank=True, null=True)),
                ('createdby', models.IntegerField(blank=True, null=True)),
                ('updated', models.DateField(blank=True, null=True)),
                ('industryid', models.IntegerField(blank=True, null=True)),
                ('initial', models.DateField(blank=True, null=True)),
                ('smtpserver', models.CharField(blank=True, max_length=100, null=True)),
                ('port', models.CharField(blank=True, max_length=100, null=True)),
                ('emailoutput', models.CharField(blank=True, max_length=100, null=True)),
                ('passwordoutput', models.CharField(blank=True, max_length=100, null=True)),
                ('roundingcycle', models.CharField(blank=True, max_length=1, null=True)),
                ('health', models.CharField(blank=True, max_length=1, null=True)),
                ('activity', models.CharField(blank=True, max_length=4000, null=True)),
                ('image', models.BinaryField(blank=True, null=True)),
                ('timezoneid', models.IntegerField(blank=True, null=True)),
                ('updatedby', models.IntegerField(blank=True, null=True)),
                ('certicatessl', models.BooleanField(blank=True, null=True)),
                ('syncpublicationid', models.IntegerField(blank=True, null=True)),
                ('synclocationid', models.IntegerField(blank=True, null=True)),
                ('paymentmethod', models.CharField(blank=True, max_length=1, null=True)),
                ('paymentcode', models.CharField(blank=True, max_length=100, null=True)),
                ('payuapilogin', models.CharField(blank=True, max_length=100, null=True)),
                ('payuapikey', models.CharField(blank=True, max_length=300, null=True)),
                ('paymentaccount', models.CharField(blank=True, max_length=100, null=True)),
                ('psetargeturl', models.CharField(blank=True, max_length=500, null=True)),
                ('esignature', models.CharField(blank=True, max_length=100, null=True)),
                ('esignaturegoodthru', models.DateField(blank=True, null=True)),
                ('esignaturepassword', models.CharField(blank=True, max_length=100, null=True)),
                ('ebillproduction', models.BooleanField(blank=True, null=True)),
                ('ebill', models.BooleanField(blank=True, null=True)),
                ('sendebill', models.CharField(blank=True, max_length=1, null=True)),
                ('hoursbyday', models.IntegerField(blank=True, null=True)),
                ('ebilladjunct', models.BooleanField(blank=True, null=True)),
                ('companyidcentral', models.IntegerField(blank=True, null=True)),
                ('paymentmethodcredit', models.CharField(blank=True, max_length=1, null=True)),
                ('emailing', models.CharField(blank=True, max_length=1, null=True)),
                ('userimap', models.CharField(blank=True, max_length=20, null=True)),
                ('passwordimap', models.CharField(blank=True, max_length=20, null=True)),
                ('configimap', models.CharField(blank=True, max_length=1000, null=True)),
                ('testid', models.CharField(blank=True, max_length=100, null=True)),
                ('databaseid', models.IntegerField(blank=True, null=True)),
                ('bienabled', models.BooleanField(blank=True, null=True)),
                ('emailoutputfe', models.CharField(blank=True, max_length=100, null=True)),
                ('passwordoutputfe', models.CharField(blank=True, max_length=100, null=True)),
                ('supercodec', models.CharField(blank=True, max_length=6, null=True)),
                ('masterclientid', models.BigIntegerField(blank=True, null=True)),
                ('budgetcostcenter', models.BooleanField(blank=True, null=True)),
                ('budgetperiod', models.BooleanField(blank=True, null=True)),
            ],
            options={
                'db_table': 'company',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Company',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('company_id', models.IntegerField(verbose_name='Company Id')),
                ('name', models.CharField(max_length=100, verbose_name='Company Name')),
                ('tax_id', models.CharField(max_length=30, verbose_name='Tax Id')),
                ('address', models.CharField(max_length=100, verbose_name='Address')),
                ('phone', models.CharField(max_length=100, verbose_name='Phone Number')),
                ('city', models.CharField(max_length=100, verbose_name='City')),
                ('legal_representative', models.CharField(max_length=150, verbose_name='Legal Representative')),
                ('enabled', models.BooleanField(default=True, verbose_name='Enabled')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
